@@ -117,7 +117,7 @@ for l in open('debian/install').readlines():
 
 index = dict()
 for filename in files:
-    print filename
+    print(filename)
     if not filename.endswith('.pro'):
         continue
     name = filename[:-4]
@@ -158,7 +158,7 @@ html_template = '''<html>
 </html>
 '''
 for category, procedures in index.items():
-    print category
+    print(category)
     with open(os.path.join('html', category.replace(' ','_')+'.html'), 'w') as html_file:
         s = '\n'.join(
             '    <tr><td><a href="{proc}.html">{PROC}</a></td><td>{desc}</td></tr>'.format(
